@@ -183,12 +183,33 @@ class CachePath(AugmentedPath):
         # to limit directory size
         return self.local_objects_dir / self.cache_key
 
-    def local_data_dir_init(self, exist_ok=True):
+    def local_data_dir_init(self, exist_ok=True, symlink_objects_to=None):
         # FIXME shouldn't this always run once the
         # first time a class is initialized and then
         # modify new to never call it again?
         self.local_data_dir.mkdir(exist_ok=exist_ok)
-        self.local_objects_dir.mkdir(exist_ok=exist_ok)
+
+        lod = self.local_objects_dir
+        if symlink_objects_to is not None:
+            # NOTE this interacts with anchorClassHere
+            # we do want to always run this local_data_dir_init
+            # to avoid hard to debug errors, which means that if
+            # a user wants to override, we have to rmdir first
+            # NOTE we do NOT rmtree here, the user needs to to that
+            # explicitly so we don't accidentally remove everything
+            # NOTE this whole design is dumb, and in cases where
+            # there are just remote objects we should be stashing
+            # them in ~/.cache or similar
+            if self.local_objects_dir.is_symlink():
+                msg = f'{lod} is already symlinked to {lod.readlink()}'
+                raise NotADirectoryError(msg)
+            elif lod.exists():
+                lod.rmdir()
+
+            lod.symlink_to(symlink_objects_to)
+        else:
+            lod.mkdir(exist_ok=exist_ok)
+
         try:
             self.trash.mkdir(exist_ok=exist_ok)
         except NotImplementedError:
@@ -545,6 +566,12 @@ class CachePath(AugmentedPath):
                 self._remote_class = self._remote_class_factory(anchor,
                                                                 self.local_class)
 
+            if (hasattr(self._remote_class, '_api_class') and
+                not hasattr(self._remote_class, '_api')):
+                # FIXME SIGH this should be one shot not a hasattr check
+                # every first time we have to get the remote for a cache
+                self._remote_class.anchorToCache(anchor)
+
             if not hasattr(self, '_remote'):
                 self._remote = self._remote_class(id, cache=self)
 
