@@ -14,8 +14,9 @@ from functools import wraps
 from itertools import chain
 try:
     import magic  # from sys-apps/file consider python-magic ?
-except (ImportError, TypeError) as e:
-    pass
+    _have_magic = True
+except (AttributeError, ImportError, TypeError) as e:
+    _have_magic = False
 
 #import psutil  # import for experimental xopen functionality
 #from Xlib.display import Display
@@ -536,10 +537,20 @@ class AugmentedPath(pathlib.Path):
 
         try:
             if self.is_dir():
+                if self.is_symlink():
+                    # see the note in shutil.rmtree about race conditions
+                    # for now we are going to hard fail if this case occures
+                    raise OSError("Cannot call rmtree on a symbolic link")
+
                 for path in self.iterdir():
-                    path.rmtree(ignore_errors=ignore_errors,
-                                onerror=onerror,
-                                DANGERZONE=DANGERZONE)
+                    if path.is_symlink():
+                        # mimic shutil behavior and don't accidentally
+                        # recurse through symlinks (keyword being curse)
+                        path.unlink()
+                    else:
+                        path.rmtree(ignore_errors=ignore_errors,
+                                    onerror=onerror,
+                                    DANGERZONE=DANGERZONE)
 
                 path = self
                 self.rmdir()
@@ -621,12 +632,20 @@ class AugmentedPath(pathlib.Path):
     def _magic_mimetype(self):
         """ This can be slow because it has to open the files. """
         if self.exists():
-            if hasattr(magic, 'detect_from_filename'):
-                # sys-apps/file python-magic api
-                return magic.detect_from_filename(self).mime_type
-            else:
-                # python-magic
-                return magic.from_file(self.as_posix(), mime=True)
+            try:
+                if hasattr(magic, 'detect_from_filename'):
+                    # sys-apps/file python-magic api
+                    return magic.detect_from_filename(self).mime_type
+                else:
+                    # python-magic
+                    return magic.from_file(self.as_posix(), mime=True)
+            except NameError as e:
+                if not _have_magic:
+                    msg = ('no module magic found from either python-magic '
+                           'or from libmagic python bindings')
+                    raise ModuleNotFoundError(msg) from e
+                else:
+                    raise e
 
     def checksum(self, cypher=default_cypher, extra_cyphers=tuple()):
         """ checksum() always recomputes from the data
@@ -922,6 +941,9 @@ class LocalPath(EatPath, AugmentedPath):
 
     def find_cache_root(self, fail=False):
         """ find the local root of the cache tree, even if we start with skips """
+        if self.is_broken_symlink():
+            return self.parent.find_cache_root(fail=fail)
+
         found_cache = None
         # try all the variants in case some symlinking weirdness is going on
         # TODO may want to detect and warn on that?
@@ -1010,7 +1032,7 @@ class LocalPath(EatPath, AugmentedPath):
 
     @property
     def meta_no_checksum(self):
-        return self._meta_maker(checksum=True)
+        return self._meta_maker(checksum=False)
 
     def _meta_maker(self, *, checksum=True, chunksize=None):
         """ setting chunksize will cause an etag to be calculated """
